==> kdepim4_4.14.10.orig.tar.xz: kdepim-4.14.10/mailcommon/collectionpage/attributeregistrar.cpp <==
/*
    Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#include "collectionpage/attributes/collectionannotationsattribute.h"
#include "collectionpage/attributes/expirecollectionattribute.h"
#include "collectionpage/attributes/newmailnotifierattribute.h"

#include <akonadi/attributefactory.h>


#ifndef KDELIBS_STATIC_LIBS
namespace {

// Anonymous namespace; function is invisible outside this file.
bool dummy()
{
  Akonadi::AttributeFactory::registerAttribute<MailCommon::CollectionAnnotationsAttribute>();
  Akonadi::AttributeFactory::registerAttribute<MailCommon::ExpireCollectionAttribute>();
  Akonadi::AttributeFactory::registerAttribute<MailCommon::NewMailNotifierAttribute>();
  return true;
}

// Called when this library is loaded.
const bool registered = dummy();

} // namespace

#else

extern bool ___MailCommon____INIT()
{
  Akonadi::AttributeFactory::registerAttribute<MailCommon::CollectionAnnotationsAttribute>();
  Akonadi::AttributeFactory::registerAttribute<MailCommon::ExpirationCollectionAttribute>();
  Akonadi::AttributeFactory::registerAttribute<MailCommon::NewMailNotifierAttribute>();

  return true;
}

#endif

==> kdepim-4.10.80.tar.xz: kdepim-4.10.80/mailcommon/collectionpage/attributeregistrar.cpp <==
/*
    Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>

    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    This library is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
    License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to the
    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
*/

#include "collectionpage/collectionannotationsattribute.h"
#include "collectionpage/expirecollectionattribute.h"

#include <akonadi/attributefactory.h>


#ifndef KDELIBS_STATIC_LIBS
namespace {

// Anonymous namespace; function is invisible outside this file.
bool dummy()
{
  Akonadi::AttributeFactory::registerAttribute<MailCommon::CollectionAnnotationsAttribute>();
  Akonadi::AttributeFactory::registerAttribute<MailCommon::ExpireCollectionAttribute>();
  return true;
}

// Called when this library is loaded.
const bool registered = dummy();

} // namespace

#else

extern bool ___MailCommon____INIT()
{
  Akonadi::AttributeFactory::registerAttribute<MailCommon::CollectionAnnotationsAttribute>();
  Akonadi::AttributeFactory::registerAttribute<MailCommon::ExpirationCollectionAttribute>();

  return true;
}

#endif
